Name:          keepalived
Version:       2.3.4
Release:       %mkrel 1
Summary:       HA monitor built upon LVS, VRRP and services poller
License:       GPLv2+
Group:         System/Cluster
URL:           https://www.keepalived.org/
Source0:       https://www.keepalived.org/software/%{name}-%{version}.tar.gz

#
# Security patches
# P100 -> ...
#

BuildRequires: systemd-units
BuildRequires: libnl3-devel
BuildRequires: net-snmp-devel
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(libipset)
BuildRequires: pkgconfig(xtables)
BuildRequires: pkgconfig(libnfnetlink)
BuildRequires: pkgconfig(libsystemd)

%description
The main goal of the keepalived project is to add a strong & robust keepalive
facility to the Linux Virtual Server project. This project is written in C with
multilayer TCP/IP stack checks. Keepalived implements a framework based on
three family checks : Layer3, Layer4 & Layer5/7. This framework gives the
daemon the ability to check the state of an LVS server pool. When one of the
servers of the LVS server pool is down, keepalived informs the Linux kernel via
a setsockopt call to remove this server entry from the LVS topology. In
addition keepalived implements an independent VRRPv2 stack to handle director
failover. So in short keepalived is a userspace daemon for LVS cluster nodes
health checks and LVS directors failover.

%prep
%autosetup -p1

%build
%configure \
        --enable-snmp --enable-snmp-rfc \
        --enable-sha1 \
        --with-init=systemd
%make_build

%install
%make_install

# Remove "samples", as we include them in %%doc
rm -rf %{buildroot}%{_sysconfdir}/%{name}/samples/

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc AUTHOR ChangeLog CONTRIBUTORS README TODO
%doc doc/keepalived.conf.SYNOPSIS doc/samples/
%license COPYING
%dir %{_sysconfdir}/keepalived/
%attr(0600, root, root) %config(noreplace) %{_sysconfdir}/keepalived/keepalived.conf.sample
%attr(0600, root, root) %config(noreplace) %{_sysconfdir}/sysconfig/keepalived
%{_unitdir}/%{name}.service
%{_bindir}/genhash
%{_sbindir}/keepalived
%{_datadir}/snmp/mibs/KEEPALIVED-MIB.txt
%{_datadir}/snmp/mibs/VRRP-MIB.txt
%{_datadir}/snmp/mibs/VRRPv3-MIB.txt
%{_mandir}/man1/genhash.1*
%{_mandir}/man5/keepalived.conf.5*
%{_mandir}/man8/keepalived.8*


%changelog
* Tue Jul 08 2025 daviddavid <daviddavid> 2.3.4-1.mga10
+ Revision: 2252402
- new version: 2.3.4
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild
+ neoclust <neoclust>
- New version 2.2.7

* Sun Apr 03 2022 umeabot <umeabot> 2.2.4-2.mga9
+ Revision: 1841522
- Mageia 9 Mass Rebuild

* Wed Dec 15 2021 luigiwalser <luigiwalser> 2.2.4-1.mga9
+ Revision: 1762146
- 2.2.4

* Tue Dec 14 2021 neoclust <neoclust> 2.2.3-3.mga9
+ Revision: 1762123
- Add P100: Fixes CVE-2021-44225 (mga#29769)

* Sat Oct 02 2021 wally <wally> 2.2.3-2.mga9
+ Revision: 1747749
- rebuild for openssl 3.0.0

* Tue Aug 17 2021 luigiwalser <luigiwalser> 2.2.3-1.mga9
+ Revision: 1741816
- 2.2.3

* Sun Apr 18 2021 daviddavid <daviddavid> 2.2.2-1.mga9
+ Revision: 1716397
- new version: 2.2.2

* Mon Mar 01 2021 daviddavid <daviddavid> 2.2.1-1.mga9
+ Revision: 1694811
- new version: 2.2.1

* Tue Nov 03 2020 akien <akien> 2.1.5-2.mga8
+ Revision: 1642005
- Rebuild for new libnetsnmp

* Wed Jul 15 2020 daviddavid <daviddavid> 2.1.5-1.mga8
+ Revision: 1606314
- new version: 2.1.5

* Sun Jul 12 2020 daviddavid <daviddavid> 2.1.4-1.mga8
+ Revision: 1605473
- new version: 2.1.4

* Wed Feb 19 2020 umeabot <umeabot> 2.0.20-2.mga8
+ Revision: 1543937
- Mageia 8 Mass Rebuild

* Thu Jan 23 2020 daviddavid <daviddavid> 2.0.20-1.mga8
+ Revision: 1482451
- new version: 2.0.20
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Oct 21 2019 daviddavid <daviddavid> 2.0.19-1.mga8
+ Revision: 1454842
- new version: 2.0.19

* Fri Jul 26 2019 daviddavid <daviddavid> 2.0.18-1.mga8
+ Revision: 1424411
- new version: 2.0.18

* Sun Jul 21 2019 daviddavid <daviddavid> 2.0.17-1.mga8
+ Revision: 1423264
- new version: 2.0.17

* Fri Apr 05 2019 daviddavid <daviddavid> 2.0.15-1.mga7
+ Revision: 1385899
- new version: 2.0.15

* Mon Mar 25 2019 daviddavid <daviddavid> 2.0.14-1.mga7
+ Revision: 1380053
- new version: 2.0.14

* Tue Feb 19 2019 daviddavid <daviddavid> 2.0.13-1.mga7
+ Revision: 1368329
- new version: 2.0.13

* Sat Jan 26 2019 daviddavid <daviddavid> 2.0.12-1.mga7
+ Revision: 1361112
- new version: 2.0.12

* Mon Jan 07 2019 daviddavid <daviddavid> 2.0.11-1.mga7
+ Revision: 1350906
- new version: 2.0.11

* Tue Nov 13 2018 daviddavid <daviddavid> 2.0.10-1.mga7
+ Revision: 1329760
- new version: 2.0.10

* Fri Nov 09 2018 daviddavid <daviddavid> 2.0.9-1.mga7
+ Revision: 1329123
- new version: 2.0.9

* Sun Oct 21 2018 daviddavid <daviddavid> 2.0.8-1.mga7
+ Revision: 1323383
- new version: 2.0.8

* Sun Sep 23 2018 umeabot <umeabot> 1.4.3-3.mga7
+ Revision: 1298516
- Mageia 7 Mass Rebuild

* Fri Apr 20 2018 daviddavid <daviddavid> 1.4.3-2.mga7
+ Revision: 1220374
- enable SNMP, SNMP RFC2787 and SHA1 support
- make sure init systemd is used instead of upstart
+ kekepower <kekepower>
- Update to version 1.4.3

* Sat Sep 09 2017 cjw <cjw> 1.2.24-2.mga7
+ Revision: 1152108
- rebuild for openssl 1.1
- pass DEBUG_CFLAGS to make to fix debug packages

* Fri Nov 11 2016 luigiwalser <luigiwalser> 1.2.24-1.mga6
+ Revision: 1066611
- 1.2.24

* Wed Aug 10 2016 luigiwalser <luigiwalser> 1.2.23-1.mga6
+ Revision: 1045273
- 1.2.23

* Mon May 09 2016 luigiwalser <luigiwalser> 1.2.20-1.mga6
+ Revision: 1011791
- 1.2.20

* Wed Mar 02 2016 umeabot <umeabot> 1.2.19-3.mga6
+ Revision: 983546
- Rebuild for openssl

* Mon Feb 15 2016 umeabot <umeabot> 1.2.19-2.mga6
+ Revision: 960843
- Mageia 6 Mass Rebuild

* Sat Dec 26 2015 luigiwalser <luigiwalser> 1.2.19-1.mga6
+ Revision: 915409
- disable strip to enable debuginfo generation
- 1.2.19
- 1.2.14
- add patch from fedora to fix data type in format string

* Wed Oct 15 2014 umeabot <umeabot> 1.2.13-3.mga5
+ Revision: 740317
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.13-2.mga5
+ Revision: 681030
- Mageia 5 Mass Rebuild

* Wed May 14 2014 luigiwalser <luigiwalser> 1.2.13-1.mga5
+ Revision: 622681
- 1.2.13

* Tue Feb 11 2014 luigiwalser <luigiwalser> 1.2.12-1.mga5
+ Revision: 589188
- 1.2.12
- BR libnl3-devel

* Sat Oct 19 2013 umeabot <umeabot> 1.2.8-2.mga4
+ Revision: 533781
- Mageia 4 Mass Rebuild

* Fri Sep 06 2013 luigiwalser <luigiwalser> 1.2.8-1.mga4
+ Revision: 475401
- 1.2.8

* Sat Jan 12 2013 umeabot <umeabot> 1.2.7-2.mga3
+ Revision: 356117
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Aug 30 2012 luigiwalser <luigiwalser> 1.2.7-1.mga3
+ Revision: 285629
- 1.2.7

* Tue Aug 21 2012 luigiwalser <luigiwalser> 1.2.6-1.mga3
+ Revision: 282788
- 1.2.6

* Sat Jul 28 2012 luigiwalser <luigiwalser> 1.2.3-2.mga3
+ Revision: 275364
- add upstream patch to fix security issue with using syslog in sighandlers

* Sat Jul 14 2012 luigiwalser <luigiwalser> 1.2.3-1.mga3
+ Revision: 270756
- 1.2.3
- remove patches 1 and 2, applied upstream

* Wed Jul 11 2012 luigiwalser <luigiwalser> 1.2.2-3.mga3
+ Revision: 269577
- add patch from debian to fix mga #4084

* Wed Jul 11 2012 luigiwalser <luigiwalser> 1.2.2-2.mga3
+ Revision: 269571
- add patch from debian to fix CVE-2011-1784

* Sat May 12 2012 colin <colin> 1.2.2-1.mga2
+ Revision: 235394
- Add LSB headers to initscripts (mga#5262)

* Sun Mar 06 2011 ennael <ennael> 1.2.2-0.mga1
+ Revision: 65416
- imported package keepalived


* Thu Mar 03 2011 zamir <zamir@mandriva.org> 1.2.2-0mdv2011.0
+ Revision: 641423
- update version

* Mon Dec 06 2010 Oden Eriksson <oeriksson@mandriva.com> 1.1.17-3mdv2011.0
+ Revision: 612562
- the mass rebuild of 2010.1 packages

* Wed Apr 21 2010 Funda Wang <fwang@mandriva.org> 1.1.17-2mdv2010.1
+ Revision: 537327
- rebuild

* Mon May 18 2009 Anne Nicolas <ennael@mandriva.org> 1.1.17-1mdv2010.0
+ Revision: 376952
- Fix group
- import keepalived


